pub struct GateQuery<'a> { /* private fields */ }Expand description
Builder for querying and filtering gates
GateQuery provides a fluent API for filtering gates by various criteria
such as parameters, scope, and other properties.
Example
use flow_gates::{GateQuery, Gate};
// In practice, you would get gates from storage
// let gate1 = /* ... */;
// let gate2 = /* ... */;
// let gate3 = /* ... */;
// let gates = vec![&gate1, &gate2, &gate3];
// let filtered: Vec<&Gate> = GateQuery::new(gates.iter().copied())
// .by_parameters("FSC-A", "SSC-A")
// .by_scope(Some("file-guid"))
// .collect();Implementations
Sourceimpl<'a> GateQuery<'a>
impl<'a> GateQuery<'a>
Sourcepub fn new(gates: impl Iterator<Item = &'a Gate>) -> Self
pub fn new(gates: impl Iterator<Item = &'a Gate>) -> Self
Create a new query builder from an iterator of gates
Arguments
gates- Iterator over gate references
Sourcepub fn by_parameters(self, x: &str, y: &str) -> Self
pub fn by_parameters(self, x: &str, y: &str) -> Self
Filter gates by parameters (channels)
Only gates that operate on the specified x and y parameters are retained.
Arguments
x- X-axis parameter namey- Y-axis parameter name